netapp_ontap.models.zapp_nvme_components_tiering API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_nvme_components_tiering`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappNvmeComponentsTieringSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappNvmeComponentsTiering object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `control: str POST`

    Storage tiering placement rules for the container(s)

    Valid choices:

    - required
    - best_effort
    - disallowed
  `object_stores: List[NasApplicationComponentsTieringObjectStores] POST`

    The object_stores field of the zapp_nvme_components_tiering.

  `policy: str GET POST`

    The storage tiering type of the application component.

    Valid choices:

    - all
    - auto
    - none
    - snapshot_only